==> touhoulittlemaid-fabric-1.20.1-0.1.0-forge1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemPicnicBasket.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import cn.sh1rocu.touhoulittlemaid.api.extension.IItemRenderer;
import cn.sh1rocu.touhoulittlemaid.util.itemhandler.ItemStackHandler;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity.PicnicBasketRender;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.other.PicnicBasketContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.tooltip.ItemContainerTooltip;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.fabric.api.screenhandler.v1.ExtendedScreenHandlerFactory;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1703;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2487;
import net.minecraft.class_2520;
import net.minecraft.class_2540;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_3222;
import net.minecraft.class_5632;
import net.minecraft.class_756;
import org.jetbrains.annotations.Nullable;

import java.util.Optional;

public class ItemPicnicBasket extends class_1747 implements ExtendedScreenHandlerFactory, IItemRenderer {
    @Environment(EnvType.CLIENT)
    @Override
    public class_756 getCustomRenderer() {
        class_310 minecraft = class_310.method_1551();
        return new PicnicBasketRender(minecraft.method_31975(), minecraft.method_31974());
    }

    private static final int PICNIC_BASKET_SIZE = 9;
    private static final String PICNIC_BASKET_TAG = "PicnicBasketContainer";

    public ItemPicnicBasket(class_2248 block) {
        super(block, (new class_1793()).method_7889(1));
    }

    public static ItemStackHandler getContainer(class_1799 stack) {
        ItemStackHandler handler = new ItemStackHandler(PICNIC_BASKET_SIZE);
        if (stack.method_7909() == InitItems.PICNIC_BASKET) {
            class_2487 tag = stack.method_7969();
            if (tag != null && tag.method_10573(PICNIC_BASKET_TAG, class_2520.field_33260)) {
                handler.deserializeNBT(tag.method_10562(PICNIC_BASKET_TAG));
            }
        }
        return handler;
    }

    public static void setContainer(class_1799 stack, ItemStackHandler itemStackHandler) {
        if (stack.method_7909() == InitItems.PICNIC_BASKET) {
            stack.method_7948().method_10566(PICNIC_BASKET_TAG, itemStackHandler.serializeNBT());
        }
    }

    // FIXME
    // Can't open GUI by right click AIR in creative game-mode, but it's effective to right click an entity that can't interact with player.
    // 未知原因导致创造模式时无法通过右键空气打开GUI，use压根没调用；但是右键不能交互的实体能正常打开，神了。
    @Override
    public class_1271<class_1799> method_7836(class_1937 worldIn, class_1657 playerIn, class_1268 handIn) {
        if (handIn == class_1268.field_5808 && playerIn instanceof class_3222 serverPlayer) {
            serverPlayer.method_17355(this/*, data -> ItemStack.STREAM_CODEC.encode(data, serverPlayer.getMainHandItem())*/);
            return class_1271.method_22427(playerIn.method_6047());
        }
        return super.method_7836(worldIn, playerIn, handIn);
    }

    @Override
    public Optional<class_5632> method_32346(class_1799 stack) {
        ItemStackHandler container = getContainer(stack);
        return Optional.of(new ItemContainerTooltip(container));
    }

    @Override
    public String method_7876() {
        return "item.touhou_little_maid.picnic_basket";
    }

    @Override
    public class_2561 method_5476() {
        return class_2561.method_43471(this.method_7876());
    }

    @Nullable
    @Override
    public class_1703 createMenu(int containerId, class_1661 playerInventory, class_1657 player) {
        return new PicnicBasketContainer(containerId, playerInventory, player.method_6047());
    }

    @Override
    public void writeScreenOpeningData(class_3222 player, class_2540 buf) {
        buf.method_10793(player.method_6047());
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.4.1-forge1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemPicnicBasket.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import cn.sh1rocu.touhoulittlemaid.api.extension.IItemRenderer;
import cn.sh1rocu.touhoulittlemaid.util.itemhandler.ItemStackHandler;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity.PicnicBasketRender;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.other.PicnicBasketContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.tooltip.ItemContainerTooltip;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.fabric.api.screenhandler.v1.ExtendedScreenHandlerFactory;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1703;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2487;
import net.minecraft.class_2520;
import net.minecraft.class_2540;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_3222;
import net.minecraft.class_5632;
import net.minecraft.class_756;
import org.jetbrains.annotations.Nullable;

import java.util.Optional;

public class ItemPicnicBasket extends class_1747 implements ExtendedScreenHandlerFactory, IItemRenderer {
    @Environment(EnvType.CLIENT)
    @Override
    public class_756 getCustomRenderer() {
        class_310 minecraft = class_310.method_1551();
        return new PicnicBasketRender(minecraft.method_31975(), minecraft.method_31974());
    }

    private static final int PICNIC_BASKET_SIZE = 9;
    private static final String PICNIC_BASKET_TAG = "PicnicBasketContainer";

    public ItemPicnicBasket(class_2248 block) {
        super(block, (new class_1793()).method_7889(1));
    }

    public static ItemStackHandler getContainer(class_1799 stack) {
        ItemStackHandler handler = new ItemStackHandler(PICNIC_BASKET_SIZE);
        if (stack.method_7909() == InitItems.PICNIC_BASKET) {
            class_2487 tag = stack.method_7969();
            if (tag != null && tag.method_10573(PICNIC_BASKET_TAG, class_2520.field_33260)) {
                handler.deserializeNBT(tag.method_10562(PICNIC_BASKET_TAG));
            }
        }
        return handler;
    }

    public static void setContainer(class_1799 stack, ItemStackHandler itemStackHandler) {
        if (stack.method_7909() == InitItems.PICNIC_BASKET) {
            stack.method_7948().method_10566(PICNIC_BASKET_TAG, itemStackHandler.serializeNBT());
        }
    }

    // FIXME
    // (概率出现)未知原因导致创造模式时无法通过右键空气打开GUI，use压根没调用；但是右键不能交互的实体能正常打开，神了。
    @Override
    public class_1271<class_1799> method_7836(class_1937 worldIn, class_1657 playerIn, class_1268 handIn) {
        if (handIn == class_1268.field_5808 && playerIn instanceof class_3222 serverPlayer) {
            serverPlayer.method_17355(this/*, data -> ItemStack.STREAM_CODEC.encode(data, serverPlayer.getMainHandItem())*/);
            return class_1271.method_22427(playerIn.method_6047());
        }
        return super.method_7836(worldIn, playerIn, handIn);
    }

    @Override
    public Optional<class_5632> method_32346(class_1799 stack) {
        ItemStackHandler container = getContainer(stack);
        return Optional.of(new ItemContainerTooltip(container));
    }

    @Override
    public String method_7876() {
        return "item.touhou_little_maid.picnic_basket";
    }

    @Override
    public class_2561 method_5476() {
        return class_2561.method_43471(this.method_7876());
    }

    @Nullable
    @Override
    public class_1703 createMenu(int containerId, class_1661 playerInventory, class_1657 player) {
        return new PicnicBasketContainer(containerId, playerInventory, player.method_6047());
    }

    @Override
    public void writeScreenOpeningData(class_3222 player, class_2540 buf) {
        buf.method_10793(player.method_6047());
    }
}
